MISSING MIGRANTS PROJECT | Latest Global Figures

Skip to main content

# Latest Global Figures

## Migrant Fatalities Worldwide

Missing Migrants Project draws on a range of sources to track deaths of migrants along migratory routes across the globe. Data from this project are published in the report “Fatal Journeys: Tracking Lives Lost during Migration,” which provides the most comprehensive global tally of migrant fatalities for 2014, and estimates deaths over the past 15 years.

With a count surpassing 40,000 fatalities since 2000, IOM calls on all the world’s governments to address what it describes as “an epidemic of crime and victimization.”

“Our message is blunt: migrants are dying who need not,” said IOM Director General William Lacy Swing, “It is time to do more than count the number of dead. It is time to engage the world to stop this violence against desperate migrants.”

The research behind this project began with the October 2013 tragedies, when over 400 migrants died in two shipwrecks near the Italian island of Lampedusa. IOM’s research indicates Europe is the world’s most dangerous destination for “irregular” migrants, with the Mediterranean costing the lives of over 3,600 this year. Around the world, over 5,000 migrants lost their lives in 2014. Approximately 5,000 are known to have died around the world in the first eleven months of 2015. Many more are unaccounted for.

- Download Fatal Journeys: Tracking lives lost during migration

# Migrant Deaths by month, 2015*

| January | February | March | April | May | June | July | August | September | October | November | December | Total to date
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
Mediterranean | 82 | 346 | 61 | 1,244 | 95 | 10 | 230 | 684 | 268 | 432 | 105 | 203 | 3,760
Europe | 0 | 1 | 2 | 15 | 2 | 2 | 11 | 81 | 11 | 6 | 5 | 3 | 139
Horn of Africa | 5 | 39 | 42 | 0 | 0 | 0 | 0 | 0 | 0 | 8 | 0 | 0 | 94
Sahara | 0 | 0 | 0 | 0 | 0 | 48 | 0 | 0 | 0 | 0 | 4 | 0 | 52
Caribbean | 2 | 0 | 0 | 44 | 0 | 0 | 0 | 0 | 0 | 3 | 0 | 0 | 49
US-Mexico | 9 | 11 | 6 | 8 | 8 | 22 | 15 | 29 | 25 | 11 | 12 | 0 | 244
Central America | 0 | 0 | 8 | 0 | 0 | 12 | 0 | 0 | 6 | 1 | 3 | 0 | 30
Southeast Asia | 63 | 0 | 8 | 0 | 333 | 0 | 0 | 24 | 61 | 0 | 4 | 0 | 736
East Asia | 0 | 15 | 0 | 0 | 0 | 0 | 0 | 0 | 0 | 0 | 0 | 0 | 15
Sub-Saharan Africa | 2 | 0 | 0 | 0 | 8 | 0 | 0 | 0 | 22 | 8 | 0 | 6 | 46
North Africa | 12 | 0 | 16 | 0 | 0 | 0 | 0 | 0 | 0 | 0 | 26 | 11 | 65
Total | 175 | 412 | 143 | 1,311 | 446 | 94 | 256 | 818 | 393 | 469 | 159 | 223 | 5,230*

5,230* to date

*Total figures include 331 deaths that are not included in the monthly breakdown because the month in which the deaths occured is not specified; 88 of these occured on the U.S. Mexico border and 243 in the Bay of Bengal (Southeast Asia). In the above chart, totals by region are correct, but monthly totals are incomplete for some months.
Note: Europe refers to the region generally, and not the European Union.

*Last updated on 26 December 2015.

Migrant deaths by region, 2015*

Migrant deaths by migrants' region of origin, 2015*

*Includes Afghanistan
**Last updated on 26 December 2015.

# Migrant Deaths by month, 2014

| January | February | March | April | May | June | July | August | September | October | November | December
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
Mediterranean | 12 | 24 | 10 | 50 | 329 | 318 | 864 | 616 | 813 | 126 | 22 | 95
US-Mexico | 12 | 8 | 11 | 12 | 11 | 20 | 14 | 9 | 11 | 13 | 8 | 8
East Africa |  |  | 251 |  |  |  |  |  |  |  |  |
Horn of Africa |  | 17 | 44 |  | 62 |  |  |  |  | 72 | 30 | 24
Bay of Bengal |  |  |  |  |  | 5 |  |  |  |  |  |
Southeast Asia |  |  |  | 5 |  | 35 | 20 | 1 | 9 | 4 |  |
Caribbean | 1 | 8 |  |  | 9 |  |  | 45 |  | 4 |  | 1
Sahara |  |  |  | 10 | 46 |  |  |  |  |  |  |
Other Europe | 2 |  | 4 |  | 2 |  | 1 | 1 |  | 2 | 40 | 2
Other Regions |  | 1 |  | 17 |  |  |  |  |  |  |  |
Total | 27 | 58 | 320 | 94 | 459 | 378 | 899 | 672 | 833 | 221 | 100 | 130

Notes: (a) 826 deaths not included here as the month in which they occured is unknown or unspecified: Southeast Asia (535), US-Mexico (170), Central America (105), and Horn of Africa (16). Total estimated deaths in 2014 were 5,017.

Missing Migrants Project by International Organization for Migration (IOM) is licensed under a Creative Commons Attribution 4.0 International License.
Based on a work at http://missingmigrants.iom.int/.